You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafodion.apache.org by an...@apache.org on 2017/09/07 01:55:15 UTC

[21/30] incubator-trafodion git commit: TRAFODION-2731 CodeCleanup: Remove obsolete, legacy and unused code

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/comexe/LateBindInfo.cpp
----------------------------------------------------------------------
diff --git a/core/sql/comexe/LateBindInfo.cpp b/core/sql/comexe/LateBindInfo.cpp
index e96d75f..c49f97e 100644
--- a/core/sql/comexe/LateBindInfo.cpp
+++ b/core/sql/comexe/LateBindInfo.cpp
@@ -42,11 +42,9 @@
 #include "exp_stdh.h"
 #include "exp_tuple_desc.h"
 #include "ComQueue.h"
-
-#if !defined(__EID) && !defined(ARKFS_OPEN)
 #include "ComResWords.h"
 #include "ComDistribution.h"
-#endif
+
 //////////////////////////////////////////////////////////////////
 //    Constructor: UninitializedMvName
 //    Description:
@@ -210,13 +208,12 @@ Lng32 LateNameInfoList::unpack(void * base, void * reallocator)
   return NAVersionedObject::unpack(base, reallocator);
 }
 
-AnsiOrNskName::AnsiOrNskName(char *inName)
+AnsiName::AnsiName(char *inName)
 {
   Int32 len;
 
   extName_[0] = '\0';
   intName_[0] = '\0';
-  isNskName_ = FALSE;
   noOfParts_ = 0;
   len = str_len(inName);
   if (len < sizeof(extName_))
@@ -234,7 +231,7 @@ AnsiOrNskName::AnsiOrNskName(char *inName)
   isValid_ = FALSE;
 }
 
-Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
+Int16 AnsiName::convertAnsiName(bool doCheck)
 {
 
   // If doCheck is false, this function will not uppercase the name and will not check for
@@ -269,7 +266,6 @@ Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
   noOfParts_ = 0;
   partPtr = parts_[noOfParts_];
   
-  isNskName_ = FALSE;
   // Remove leading spaces
   while (*ptr != '\0' && *ptr == ' ')
     *ptr++;  
@@ -284,7 +280,6 @@ Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
 	  return -1;
 	else
 	{
-	  isNskName_ = TRUE;
 	  if (*(ptr) == '$')
 	     dollarFound = TRUE;
 	}
@@ -293,10 +288,7 @@ Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
   }
   else
     return -1; // Error when all are spaces
-  if (isNskName_)
-     partCheckLen = 8;	// NskNameLen
-  else
-     partCheckLen = ComAnsiNamePart::MAX_IDENTIFIER_INT_LEN;
+  partCheckLen = ComAnsiNamePart::MAX_IDENTIFIER_INT_LEN;
   while(*ptr != '\0')
   {
     switch (*ptr)
@@ -364,16 +356,10 @@ Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
 	   ptr++;
 	   totalLen++;
 	}
-	if (isNskName_)
-	{
-	  if (noOfParts_ >= 3)  
-  	    return -1;
-	}
-	else
-	{
-	  if (noOfParts_ >= 2)
-	    return -1;
-	}
+
+        if (noOfParts_ >= 2)
+          return -1;
+
 	partBegin = TRUE;
 	partLen = 0;
 	*partPtr = '\0';
@@ -386,41 +372,11 @@ Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
 	delimited = FALSE;
 	noOfParts_++;
         partPtr = parts_[noOfParts_];
-	if (isNskName_)
-	{
-	  if (noOfParts_ == 1 && *ptr != '\0')
+        if (*ptr != '\0' && *ptr != '\"') // Check that char is Alpha if not in quotes
 	  {
-	     if (! dollarFound)
-	     {
-	       if (*ptr != '$')
-		 return -1;
-	     }
-	     else
-	     {
-	       if (*ptr != '\"')
-	       {
-		 if (! isAlpha8859_1((unsigned char)(*ptr)))
-		  return -1;
-	       } 
-	     }
+            if (! isAlpha8859_1((unsigned char)(*ptr)))
+              return -1;
 	  }
-	  else
-	  {
-	    if (*ptr != '\0' && *ptr != '\"')
-	    {
-	      if (! isAlpha8859_1((unsigned char)(*ptr)))
-		return -1;
-	    }
-  	  }
-	}
-	else
-	{
-	  if (*ptr != '\0' && *ptr != '\"') // Check that char is Alpha if not in quotes
-	  {
-	      if (! isAlpha8859_1((unsigned char)(*ptr)))
-		return -1;
-	  }
-	}
       }
       else
       {
@@ -547,7 +503,7 @@ Int16 AnsiOrNskName::convertAnsiOrNskName(bool doCheck)
   return 0;
 }
 
-Int16 AnsiOrNskName::extractParts(Lng32 &numParts,
+Int16 AnsiName::extractParts(Lng32 &numParts,
 		char *parts[])
 {
   Int16 ret;
@@ -555,7 +511,7 @@ Int16 AnsiOrNskName::extractParts(Lng32 &numParts,
 
   if (! isValid_)
   {
-    if ((ret = convertAnsiOrNskName(FALSE)) == -1)
+    if ((ret = convertAnsiName(FALSE)) == -1)
       return ret;
   }
   numParts = noOfParts_;
@@ -564,7 +520,7 @@ Int16 AnsiOrNskName::extractParts(Lng32 &numParts,
   return 0;
 }
 
-Int16 AnsiOrNskName::equals(AnsiOrNskName *inName)
+Int16 AnsiName::equals(AnsiName *inName)
 {
   // Check if the external name are equal 
   if (str_cmp_ne(inName->extName_, extName_) == 0)
@@ -573,12 +529,12 @@ Int16 AnsiOrNskName::equals(AnsiOrNskName *inName)
   {
     if (! isValid_)
     {
-      if (convertAnsiOrNskName(FALSE) != 0)
+      if (convertAnsiName(FALSE) != 0)
 	return -1;
     }
     if (! inName->isValid_)
     {
-      if (inName->convertAnsiOrNskName() != 0)
+      if (inName->convertAnsiName() != 0)
 	  return -1;
     }
     if (str_cmp_ne(inName->intName_, intName_) == 0)
@@ -588,45 +544,45 @@ Int16 AnsiOrNskName::equals(AnsiOrNskName *inName)
   }
 }
 
-char *AnsiOrNskName::getInternalName()
+char *AnsiName::getInternalName()
 {
   if (! isValid_)
   {
-    if (convertAnsiOrNskName() != 0)
+    if (convertAnsiName() != 0)
       return NULL;
   }
   return intName_;
 }
 
-char *AnsiOrNskName::getExternalName()
+char *AnsiName::getExternalName()
 {
-  if (isValid_ && !isNskName_)
+  if (isValid_)
     // Build the ANSI name from the individual parts
     ComBuildANSIName (parts_[0], parts_[1], parts_[2], extName_, sizeof(extName_));
   return extName_;
 }
 
-AnsiOrNskName *LateNameInfo::getLastUsedName(NAMemory *heap)
+AnsiName *LateNameInfo::getLastUsedName(NAMemory *heap)
 {
-  AnsiOrNskName *ansiName;
+  AnsiName *ansiName;
   NABasicPtr    nameStr;
   void *  	addr;
 
   if (! isLastUsedNameEmbedded())
   {
     addr = *((void **)lastUsedAnsiName_);
-    return (AnsiOrNskName *)addr;
+    return (AnsiName *)addr;
   }
   else
   {
     if (heap == NULL)
       return NULL;
     if (isLastUsedNameCompEmbedded())
-      ansiName = new (heap) AnsiOrNskName(lastUsedAnsiName_);
+      ansiName = new (heap) AnsiName(lastUsedAnsiName_);
     else
     {
       memcpy((void *)&nameStr, lastUsedAnsiName_, sizeof(nameStr));
-      ansiName = new (heap) AnsiOrNskName(nameStr.getPointer());
+      ansiName = new (heap) AnsiName(nameStr.getPointer());
     }
     *(void **)lastUsedAnsiName_ = (void *)ansiName;
     setLastUsedNameMode(TRUE);
@@ -634,7 +590,7 @@ AnsiOrNskName *LateNameInfo::getLastUsedName(NAMemory *heap)
   }
 }
 
-Int16 AnsiOrNskName::fillInMissingParts(char *schemaName)
+Int16 AnsiName::fillInMissingParts(char *schemaName)
 {
     char *ptr;
     char *tgt;
@@ -647,11 +603,11 @@ Int16 AnsiOrNskName::fillInMissingParts(char *schemaName)
 
     if (! isValid_)
     {
-      if (convertAnsiOrNskName() != 0)
+      if (convertAnsiName() != 0)
 	return -1;
     }
     partsToFill = (Int16)(3 - noOfParts_);
-    if (isNskName_ || partsToFill == 0)
+    if (partsToFill == 0)
       return 1;
     // Remove leading blanks in the schemaName
     ptr = schemaName;
@@ -730,7 +686,7 @@ Int16 AnsiOrNskName::fillInMissingParts(char *schemaName)
     extName_[totalLen] ='\0';
     isValid_ = FALSE;
     isError_ = FALSE;
-    retCode = convertAnsiOrNskName();
+    retCode = convertAnsiName();
     if (retCode != -1 && noOfParts_ != 3)
       retCode = -1;
     return retCode;
@@ -762,9 +718,9 @@ void LateNameInfo::setLastUsedName(char *name, NAMemory *heap)
 
 }
 
-void LateNameInfo::setLastUsedName(AnsiOrNskName *name)
+void LateNameInfo::setLastUsedName(AnsiName *name)
 {
-  AnsiOrNskName *ansiName;
+  AnsiName *ansiName;
 
   if (! isLastUsedNameEmbedded())
   {
@@ -802,7 +758,7 @@ void LateNameInfo::setCompileTimeName(char *name, NAMemory *heap)
 
 char *LateNameInfo::lastUsedAnsiName()
 {
-  AnsiOrNskName *name;
+  AnsiName *name;
   NABasicPtr	nameStr;
   
   name = getLastUsedName(NULL);
@@ -822,7 +778,7 @@ char *LateNameInfo::lastUsedAnsiName()
 
 char *LateNameInfo::lastUsedExtAnsiName()
 {
-  AnsiOrNskName *name;
+  AnsiName *name;
   NABasicPtr     nameStr;
 
   name = getLastUsedName(NULL);
@@ -842,7 +798,7 @@ char *LateNameInfo::lastUsedExtAnsiName()
 
 void LateNameInfo::zeroLastUsedAnsiName()
 { 
-  AnsiOrNskName *ansiName;
+  AnsiName *ansiName;
 
   if (! isLastUsedNameEmbedded())
   {
@@ -917,138 +873,6 @@ void LateNameInfo::resetRuntimeFlags()
       runtimeFlags_ = 0; 
 }
 
-bool AnsiOrNskName::isNskName()
-{
-  if (! isValid_)
-  {
-    if (convertAnsiOrNskName() != 0)
-      return FALSE;
-  }
-  return isNskName_;
-}
-
-Int16 AnsiOrNskName::updateNSKInternalName(char *inName)
-{
-  if (isError_ || (! isValid_))
-    return -1;
-  if (noOfParts_ == 4)
-    return -1;
-  char *ptr, *tgt, *partPtr;
-  Int32 len;
-  Int16 partsToFill, partsFilled;
-  
-
-  char temp[ComAnsiNamePart::MAX_ANSI_NAME_EXT_LEN+1];
-
-  len = str_len(extName_);
-  str_cpy_all(temp, extName_, len);
-  temp[len] = '\0';
-
-  partsToFill = (Int16)(4 - noOfParts_);
-  partsFilled = 0;
-  // Move down the parts
-  Int32 i, j;
-  for (i = 3, j = noOfParts_-1 ; j >= 0 ; i--, j--)
-     memcpy(parts_[i], parts_[j], ComAnsiNamePart::MAX_IDENTIFIER_INT_LEN+1);
-  ptr = inName;
-  partPtr = parts_[0];
-  tgt = extName_;
-  // Copy the system name and volume name if needed
-  while (*ptr != '\0')
-  {
-    *tgt = *ptr;
-    tgt++;
-    if (*ptr == '.')
-    {
-      *partPtr = '\0';
-      partsFilled++;
-      partPtr = parts_[partsFilled];
-      if (partsFilled == partsToFill || partsFilled == 2)
-      {
-        ptr++;
-        break;
-      }
-    }
-    else
-    {
-      *partPtr = *ptr;
-      partPtr++;
-    }
-    ptr++;
-  }
-  *tgt = '\0';
-  // Copy the subvolume and quote if reserved name in extName
-  if (partsFilled < partsToFill)
-  {
-    while (*ptr != '\0' && *ptr != '.')
-    {
-      *partPtr = *ptr;
-      ptr++;
-      partPtr++;
-    }
-    // zero-terminate
-    *partPtr = '\0';
-
-    if (*ptr == '\0')
-      return -1;
-    if (IsSqlReservedWord(parts_[2]))
-    {
-      *tgt = '\"';
-      tgt++;
-      *tgt = '\0';
-      str_cat(extName_, parts_[2], extName_);
-      str_cat(extName_, "\".", extName_);
-    }
-    else
-    {
-      str_cat(extName_, parts_[2], extName_);
-      str_cat(extName_, ".", extName_);
-    }
-    partsFilled++;
-  }
-  str_cat(extName_, temp, extName_);
-  // copy the internal name
-  len = str_len(inName);
-  str_cpy_all(intName_, inName, len);
-  intName_[len] = '\0';
-  noOfParts_ = 4;
-  isNskName_ = TRUE;
-  return 0;
-}
-
-Int16 AnsiOrNskName::quoteNSKExtName()
-{
-  Int32 len;
-
-  if (isError_ || (! isValid_))
-    return -1;
-  if (noOfParts_ != 4)
-    return -1;
-  if (IsSqlReservedWord(parts_[3]))
-  {
-    // copy just the table name with quotes
-    extName_[0] = '\"';
-    len = str_len(parts_[3]);
-    str_cpy_all(extName_+1, parts_[3], len);
-    extName_[len+1] =  '\"';
-    extName_[len+2] = '\0';
-    noOfParts_ = 1;
-    return updateNSKInternalName(intName_);
-  }
-  else
-  if (IsSqlReservedWord(parts_[2]))
-  {
-    // copy just the table name
-    len = str_len(parts_[3]);
-    str_cpy_all(extName_, parts_[3], len);
-    extName_[len] = '\0';
-    noOfParts_ = 1;
-    return updateNSKInternalName(intName_);
-  }
-  else
-    return 0;
-}
-
 ///////////////////////////////////////////////////////////////////
 // class TrafSimilarityTableInfo
 ///////////////////////////////////////////////////////////////////

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/comexe/LateBindInfo.h
----------------------------------------------------------------------
diff --git a/core/sql/comexe/PartInputDataDesc.cpp b/core/sql/comexe/PartInputDataDesc.cpp
index 3424ee6..894c42a 100644
--- a/core/sql/comexe/PartInputDataDesc.cpp
+++ b/core/sql/comexe/PartInputDataDesc.cpp
@@ -45,7 +45,6 @@
 #include "ExpAtp.h"
 #include "ComPackDefs.h"
 
-#define NA_NO_C_RUNTIME
 #include "BaseTypes.h"
 
 // -----------------------------------------------------------------------
@@ -444,7 +443,7 @@ Lng32 ExHash2PartInputData::unpack(void * base, void * reallocator)
 // This method returns the virtual function table pointer for an object
 // with the given class ID; used by NAVersionedObject::driveUnpack().
 // -----------------------------------------------------------------------
-NA_EIDPROC char *ExPartInputDataDesc::findVTblPtr(short classID)
+char *ExPartInputDataDesc::findVTblPtr(short classID)
 {
   char *vtblPtr;
   switch (classID)

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/comexe/QueueIndex.h
----------------------------------------------------------------------
diff --git a/core/sql/comexe/QueueIndex.h b/core/sql/comexe/QueueIndex.h
index 6ce1d02..f12cb16 100644
--- a/core/sql/comexe/QueueIndex.h
+++ b/core/sql/comexe/QueueIndex.h
@@ -39,12 +39,7 @@
 // definition of queue_index needs to be known as compiler time since
 // objects of it are passed as arguments to the TDB constructors.
 
-#ifdef NA_64BIT
-// dg64 - 32-bits on disk
 typedef UInt32  queue_index;
-#else
-typedef ULng32 queue_index;
-#endif
 
 #endif
 

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/comexe/SqlTableOpenInfo.h
----------------------------------------------------------------------
diff --git a/core/sql/comexe/SqlTableOpenInfo.h b/core/sql/comexe/SqlTableOpenInfo.h
index 44be07e..2377ae2 100644
--- a/core/sql/comexe/SqlTableOpenInfo.h
+++ b/core/sql/comexe/SqlTableOpenInfo.h
@@ -134,7 +134,6 @@ public:
   NABoolean distributeOpens() { return (openFlags_ & DISTRIBUTE_OPENS) != 0; }
   NABoolean reuseOpens()      { return (openFlags_ & REUSE_OPENS) != 0; }
   NABoolean reuseOpensForWrite()      { return (openFlags_ & REUSE_OPENS_FOR_WRITE) != 0; }
-  NABoolean validateRforkTS() { return (openFlags_ & VALIDATE_RFORK_TS) != 0;}
   NABoolean readProtectedOpen() { return (openFlags_ & READ_PROTECTED_OPEN) != 0;}
   NABoolean insertToNonAudited() { return (openFlags_ & INSERT_TO_NONAUDITED_OPEN) != 0;}
 
@@ -217,9 +216,6 @@ public:
      { (v ? otherFlags_ |= IS_MX_METADATA_TABLE : otherFlags_ &= ~IS_MX_METADATA_TABLE); }
  void setIsInsertOfUpdateCK(NABoolean v)
      { (v ? otherFlags_ |= INSERT_OF_UPDATE_CK : otherFlags_ &= ~INSERT_OF_UPDATE_CK); }
- void setValidateRforkTS(NABoolean v) 	      
-     { (v ? openFlags_ |= VALIDATE_RFORK_TS : openFlags_ &= ~VALIDATE_RFORK_TS); }
-
 
   inline 
   void setSubjectTable(NABoolean v)
@@ -412,17 +408,6 @@ private:
     // Tables are closed if the process is exited, or if user id changes.
     REUSE_OPENS = 0x0100,
 
-    // if this flag is set, then we compare the compile TS against the
-    // redef TS of the rfork.
-    // This is to implement the feature of not blowing away opens of
-    // running queries unless it is required. 
-    // With this feature, catman changes the redef TS of the rfork for
-    // the cases where running queries need not be disrupted. For ex, if
-    // permissions are revoked. On the next execution of the query, executor
-    // validates the compile timestamp against the TS of rfork and recompiles,
-    // if rfork TS is greater.
-    VALIDATE_RFORK_TS = 0x0200,
-
     // sets exclusion mode to ARK_DML_PROTECTED. This does a read protected
     // open which prevents any write access to the table.
     READ_PROTECTED_OPEN = 0x0400,

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/BaseTypes.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/BaseTypes.cpp b/core/sql/common/BaseTypes.cpp
index ae03ca8..0689333 100644
--- a/core/sql/common/BaseTypes.cpp
+++ b/core/sql/common/BaseTypes.cpp
@@ -64,9 +64,7 @@ extern void my_mpi_fclose();
 #include "CompException.h"
 #include "StmtCompilationMode.h"
 
-#if defined(NA_LINUX) && !defined(__EID)
 extern void releaseRTSSemaphore();  // Functions implemented in SqlStats.cpp
-#endif
 
 // LCOV_EXCL_START :dpm
 void NADebug()
@@ -104,9 +102,7 @@ void NAArkcmpExceptionEpilogue()
 // wrapper for exit(), calling NAError_stub_for_breakpoints() first
 void NAExit(Int32 status)
 {
-#ifndef __EID
     NAAssertMutexLock(); // Serialize termination
-#endif
     releaseRTSSemaphore();
   if (status)
     NAError_stub_for_breakpoints(); // LCOV_EXCL_LINE :dpm

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/BaseTypes.h
----------------------------------------------------------------------
diff --git a/core/sql/common/BaseTypes.h b/core/sql/common/BaseTypes.h
index 3d3bc6a..6bea280 100644
--- a/core/sql/common/BaseTypes.h
+++ b/core/sql/common/BaseTypes.h
@@ -237,14 +237,8 @@ extern void NADebug();
 // Abnormal program termination
 // -----------------------------------------------------------------------
 
-#include "SqlExportDllDefines.h"
-
-#ifdef __EID
-#define ABORT(msg)	{}
-#else
 #define ABORT(msg)	NAAbort (__FILE__, __LINE__, (msg))
-extern void SQLEXPORT_LIB_FUNC NAAbort (const char *, Int32, const char *);
-#endif
+extern void NAAbort (const char *, Int32, const char *);
 
 // -----------------------------------------------------------------------
 // the NAString datatype used to be Tools.h++'s RWCString; now it's a

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/BigNumHelper.h
----------------------------------------------------------------------
diff --git a/core/sql/common/BigNumHelper.h b/core/sql/common/BigNumHelper.h
index c93abdc..eb4f0aa 100644
--- a/core/sql/common/BigNumHelper.h
+++ b/core/sql/common/BigNumHelper.h
@@ -57,14 +57,12 @@ class BigNumHelper {
 public:
 
 // The following method adds two Big Nums (without signs).
-NA_EIDPROC
 static short AddHelper(Lng32 dataLength,
 		       char * leftData,
 		       char * rightData,
 		       char * resultData);
 
 // The following method subtracts one Big Num from another (without signs).
-NA_EIDPROC
 static short SubHelper(Lng32 dataLength,
 		       char * leftData,
 		       char * rightData,
@@ -73,7 +71,6 @@ static short SubHelper(Lng32 dataLength,
 // The following method multiplies two Big Nums (without signs).
 // The assumption is that the result is big enough to hold the
 // product.
-NA_EIDPROC
 static short MulHelper(Lng32 resultLength,
                        Lng32 leftLength,
 		       Lng32 rightLength,
@@ -84,7 +81,6 @@ static short MulHelper(Lng32 resultLength,
 // The following method divides one Big Num by another (both without signs),
 // only if the divisor fits in an unsigned short. It returns 1 if there is
 // a remainder, 0 if there is no remainder, and -1 if there is an error.
-NA_EIDPROC
 static short SimpleDivHelper(Lng32 dividendLength,
 			     Lng32 divisorLength,
 			     char * dividendData,
@@ -93,7 +89,6 @@ static short SimpleDivHelper(Lng32 dividendLength,
 
 // The following method divides one Big Num by another (both without signs).
 // It returns 1 if there is a remainder, 0 if there is no remainder. 
-NA_EIDPROC
 static short DivHelper(Lng32 dividendLength,
 		       Lng32 divisorLength,
 		       char * dividendData,
@@ -104,7 +99,6 @@ static short DivHelper(Lng32 dividendLength,
 // The following method converts a given Big Num (without sign) into
 // its equivalent BCD string representation (with the more significant decimal
 // digits in the lower addresses).
-NA_EIDPROC
 static short ConvBigNumToBcdHelper(Lng32 sourceLength,
 			           Lng32 targetLength,
 			           char * sourceData,
@@ -114,7 +108,6 @@ static short ConvBigNumToBcdHelper(Lng32 sourceLength,
 // The following method converts a given BCD string representation (without sign,
 // and with the more significant decimal digits in the lower addresses) 
 // into its equivalent Big Num representation.
-NA_EIDPROC
 static short ConvBcdToBigNumHelper(Lng32 sourceLength,
 			           Lng32 targetLength,
 			           char * sourceData,
@@ -123,7 +116,6 @@ static short ConvBcdToBigNumHelper(Lng32 sourceLength,
 // The following method converts a given Big Num (with sign) into
 // its equivalent BCD string representation (with the more significant
 // decimal digits in the lower addresses).
-NA_EIDPROC
 static short ConvBigNumWithSignToBcdHelper(Lng32 sourceLength,
 			                   Lng32 targetLength,
 			                   char * sourceData,
@@ -133,7 +125,6 @@ static short ConvBigNumWithSignToBcdHelper(Lng32 sourceLength,
 // The following method converts a given BCD string representation 
 // (with sign, and with the more significant decimal digits in the lower
 // addresses) into its equivalent Big Num representation.
-NA_EIDPROC
 static short ConvBcdToBigNumWithSignHelper(Lng32 sourceLength,
 			                   Lng32 targetLength,
 			                   char * sourceData,
@@ -142,7 +133,6 @@ static short ConvBcdToBigNumWithSignHelper(Lng32 sourceLength,
 // The following method converts a given Big Num (without sign) into
 // its equivalent ASCII string representation (with the more significant
 // decimal digits in the lower addresses).
-NA_EIDPROC
 static short ConvBigNumToAsciiHelper(Lng32 sourceLength,
 			             Lng32 targetLength,
 			             char * sourceData,
@@ -152,7 +142,6 @@ static short ConvBigNumToAsciiHelper(Lng32 sourceLength,
 // The following method converts a given ASCII string representation 
 // (without sign, and with the more significant decimal digits in the lower
 // addresses) into its equivalent Big Num representation.
-NA_EIDPROC
 static short ConvAsciiToBigNumHelper(Lng32 sourceLength,
 			             Lng32 targetLength,
 			             char * sourceData,
@@ -161,7 +150,6 @@ static short ConvAsciiToBigNumHelper(Lng32 sourceLength,
 // The following method converts a given Big Num (with sign) into
 // its equivalent ASCII string representation (with the more significant
 // decimal digits in the lower addresses).
-NA_EIDPROC
 static short ConvBigNumWithSignToAsciiHelper(Lng32 sourceLength,
 			                     Lng32 targetLength,
 			                     char * sourceData,
@@ -171,7 +159,6 @@ static short ConvBigNumWithSignToAsciiHelper(Lng32 sourceLength,
 // The following method converts a given ASCII string representation 
 // (with sign, and with the more significant decimal digits in the lower
 // addresses) into its equivalent Big Num representation.
-NA_EIDPROC
 static short ConvAsciiToBigNumWithSignHelper(Lng32 sourceLength,
 			                     Lng32 targetLength,
 			                     char * sourceData,
@@ -180,26 +167,22 @@ static short ConvAsciiToBigNumWithSignHelper(Lng32 sourceLength,
 // Given a desired precision of a Big Num, the following method calculates 
 // the required storage length (including the sign). We assume that the
 // precision is > 0.  Storage will always be at a minimum 8 bytes.
-NA_EIDPROC
 static Lng32 ConvPrecisionToStorageLengthHelper(Lng32 precision);
 
 // The following method converts an integer, 10^exponent, to a Big Num 
 // representation (without sign). The given exponent should be >= 0.
-NA_EIDPROC
 static short ConvPowersOfTenToBigNumHelper(Lng32 exponent,
                                            Lng32 targetLength,
                                            Lng32 * finalTargetLength,
                                            char * targetData);
 
 // The following converts an Int64 to a Big Num (with sign).
-NA_EIDPROC
 static short ConvInt64ToBigNumWithSignHelper(Lng32 targetLength,
                                              Int64 sourceData,
                                              char * targetData,
                                              NABoolean isUnsigned);
 
 // The following converts a Big Num (with sign) into an Int64.
-NA_EIDPROC
 static short ConvBigNumWithSignToInt64Helper(Lng32 sourceLength,
                                              char * sourceData,
                                              void * targetData,
@@ -215,7 +198,6 @@ static short ConvBigNumWithSignToInt64Helper(Lng32 sourceLength,
 //   2: the result was rounded down to LLONG_MAX
 //   3: the result was rounded up
 //   4: the result was rounded down
-NA_EIDPROC
 static short ConvBigNumWithSignToInt64AndScaleHelper(Lng32 sourceLength,
                                                      char * sourceData,
                                                      Int64 * targetData,
@@ -223,7 +205,6 @@ static short ConvBigNumWithSignToInt64AndScaleHelper(Lng32 sourceLength,
                                                      NAMemory * heap);
 
 // The following converts a Big Num to a Big Num.
-NA_EIDPROC
 static short ConvBigNumWithSignToBigNumWithSignHelper(Lng32 sourceLength,
                                                       Lng32 targetLength,
                                                       char * sourceData,

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/Collections.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/Collections.cpp b/core/sql/common/Collections.cpp
index 04c953d..2da7f98 100644
--- a/core/sql/common/Collections.cpp
+++ b/core/sql/common/Collections.cpp
@@ -73,10 +73,8 @@ void NACollection<T>::insert(CollIndex posToInsert,
 			     CollIndex newUsage)
 {
   // is a valid position and usage given?
-#ifndef PRIV_SRL 
   assert((posToInsert < MAX_COLL_INDEX) AND
 	 (newUsage    != UNUSED_COLL_ENTRY));
-#endif // PRIV_SRL 
   
   // do we need to increase the size?
   if (posToInsert >= maxLength_)
@@ -124,16 +122,12 @@ CollIndex NACollection<T>::resize(CollIndex newSize)
 	}
   
       // shouldn't even come close to this
-#ifndef PRIV_SRL 
       assert (newSize < MAX_COLL_INDEX);
-#endif // PRIV_SRL 
 
       // use a temp collection with the new size
       NACollection<T> newOne(heap_,newSize);
     
-#ifndef PRIV_SRL 
       assert(newSize >= usedLength_);
-#endif // PRIV_SRL 
 
       for (CollIndex i = FIRST_COLL_INDEX; i < usedLength_; i++)
 	{
@@ -175,9 +169,7 @@ template <class T> void NACollection<T>::allocate(CollIndex initLen)
 {
   // NOTE: this assumes that the heap_ data member has been set.
   // No other data members need to be set before calling this.
-#ifndef PRIV_SRL 
   assert(initLen < MAX_COLL_INDEX);
-#endif // PRIV_SRL 
  
   maxLength_  = initLen;
   usedLength_ = 0;
@@ -1394,16 +1386,12 @@ K* NAHashBucket<K,V>::remove(K* key)
 template <class K, class V>
 NAHashDictionary<K,V>::NAHashDictionary(
 // see long detailed comment in Collections.h about the hash function param.
-//#if !defined(NA_UNIX) || defined(NA_LINUX)
 			ULng32 (*hashFunction)(const K &), 
-//#endif
 			ULng32 hashSize,
 			NABoolean enforceUniqueness,
 			NAMemory* heap)
 			: heap_(heap),
-//#if !defined(NA_UNIX) || defined(NA_LINUX)
 		       hash_(hashFunction),
-//#endif
 		       entries_(0), 
 		       enforceUniqueness_(enforceUniqueness)
 {
@@ -1414,9 +1402,7 @@ template <class K, class V>
 NAHashDictionary<K,V>::NAHashDictionary (const NAHashDictionary<K,V> & other,
                                          NAMemory * heap) 
      : heap_( (heap==NULL) ? other.heap_ : heap ),
-//#if !defined(NA_UNIX) || defined(NA_LINUX)
        hash_(other.hash_),
-//#endif
        entries_(other.entries_), 
        enforceUniqueness_(other.enforceUniqueness_)
 {
@@ -1471,7 +1457,6 @@ void NAHashDictionary<K,V>::createHashTable(ULng32 hashSize)
 template <class K, class V>
 ULng32 NAHashDictionary<K,V>::getHashCode(const K& key) const
 {
-//#if defined(NA_UNIX) && !defined(NA_LINUX)
   // use the key's hash method to get the hash value
 //  unsigned long hashValue = key.hash() % hashSize_;
 //#else

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/Collections.h
----------------------------------------------------------------------
diff --git a/core/sql/common/Collections.h b/core/sql/common/Collections.h
index 915dbf1..acccd94 100644
--- a/core/sql/common/Collections.h
+++ b/core/sql/common/Collections.h
@@ -43,8 +43,6 @@
 
 
 
-//#include "SqlExportDllDefines.h"
-
 /**
 *** _m64_popcnt is an instruction-level intrinsic routine supported in the
 *** IA64 compiler.  It quickly counts the number of bits set in a 64-bit 
@@ -353,30 +351,25 @@ protected:                                                // NT_PORT SK 04/08/97
 #endif // ! NA_MSVC && ! NA_NO_FRIENDS_WITH_TEMPLATE_REFS
 
   // default constructor(empty collection)
-  NA_EIDPROC NACollection(CollIndex initLen = 0) : heap_(NULL)
+  NACollection(CollIndex initLen = 0) : heap_(NULL)
   { allocate(initLen); }
 
   // constructor for a collection with user-defined heap management
-  NA_EIDPROC NACollection(CollHeap *heap, CollIndex initLen = 0) : heap_(heap)
+  NACollection(CollHeap *heap, CollIndex initLen = 0) : heap_(heap)
   { allocate(initLen); }
 
   // copy ctor
-  NA_EIDPROC NACollection(const NACollection<T> &other, CollHeap *heap=0)
+  NACollection(const NACollection<T> &other, CollHeap *heap=0)
        : heap_( (heap==NULL) ? other.heap_ : heap )
   { copy(other); }
 
   // virtual destructor
-#if   !defined(PRIV_SRL) 
-  NA_EIDPROC virtual ~NACollection();
-#else
-  NA_EIDPROC ~NACollection();
-#endif // NA_HSC 
-
+  virtual ~NACollection();
 
   // copy another collection into this one
   // NOTE: this method is called by a constructor and it
   // assumes that the collection is in the deallocated state!!!
-  NA_EIDPROC void copy(const NACollection<T> &other) ;
+  void copy(const NACollection<T> &other) ;
 
   // assignment operator (deep copy instead of shallow one)
   inline NACollection<T> & operator =(const NACollection<T> &other)
@@ -389,29 +382,29 @@ protected:                                                // NT_PORT SK 04/08/97
   void clearFrom( CollIndex entry );
 
   // return entry ix(create entry, if it doesn't exist already)
-  NA_EIDPROC T & rawEntry(CollIndex ix);
+  T & rawEntry(CollIndex ix);
 
   // overloaded operator [] to access elements of the collection
  T & usedEntry(CollIndex ix)
   {
-#if defined(_DEBUG) && !defined(PRIV_SRL)
+#if defined(_DEBUG)
     if((ix >= usedLength_) OR
        (usages_[ix] == UNUSED_COLL_ENTRY))
       ABORT("referencing an unused element of a collection");
-#endif // PRIV_SRL 
+#endif
     return arr_[ix];
   }
 
   // the const version of usedEntry
  const T & constEntry(CollIndex ix) const 
   {
-#if defined(_DEBUG) && !defined(PRIV_SRL)
+#if defined(_DEBUG)
     if((ix >= usedLength_) OR
        (usages_[ix] == UNUSED_COLL_ENTRY)) 
       {
 	ABORT("referencing an unused element of a collection");
       }
-#endif // PRIV_SRL 
+#endif
     return arr_[ix];
   }
   
@@ -433,7 +426,7 @@ protected:                                                // NT_PORT SK 04/08/97
     { return sizeof(*this) + (maxLength_ * (sizeof(T)+sizeof(CollIndex))); }
 
   // Resize the arrays to a new size(return new size)
-  NA_EIDPROC CollIndex resize(CollIndex newSize);  
+  CollIndex resize(CollIndex newSize);  
 
   inline void setUsage(CollIndex pos, CollIndex newUsage)
   {
@@ -446,10 +439,10 @@ protected:                                                // NT_PORT SK 04/08/97
 
   // allocate the arrays(used in constructor, don't assume
   // that the data members except "heap_" are initialized yet)
-  NA_EIDPROC void allocate(CollIndex initLen);
+  void allocate(CollIndex initLen);
 
   //inline void deallocate()
-  NA_EIDPROC virtual void deallocate()
+  virtual void deallocate()
   {
     // NOTE: dirty deallocate, no cleanup!!!
     if ( heap_ == NABasicObject::systemHeapPtr() )
@@ -525,7 +518,7 @@ protected:                                                // NT_PORT SK 04/08/97
     return;
   }
 
-  NA_EIDPROC void insert(CollIndex posToInsert,
+  void insert(CollIndex posToInsert,
 	      const T   &newElement,
 	      CollIndex newUsage = NULL_COLL_INDEX);
 
@@ -632,7 +625,7 @@ const Lng32 bitsSet[] = {
 // 
 // ***********************************************************************
 
-NA_EIDPROC inline Lng32 firstOne( ULng32 x )
+inline Lng32 firstOne( ULng32 x )
 {
   #define FIRSTHALFWORDBITS            0xFFFF0000
   #define FIRSTQUARTERWORDBITS         0xFF000000
@@ -839,7 +832,6 @@ NA_EIDPROC inline Lng32 firstOne( ULng32 x )
 //        to compiler intrinsic _m64_popcnt - much *MUCH* faster.
 // 
 // ***********************************************************************
-NA_EIDPROC
 inline Lng32 lastOne( ULng32 x )
 {
   #define LASTHALFWORDBITS             0x0000FFFF
@@ -1040,7 +1032,6 @@ inline Lng32 lastOne( ULng32 x )
 // argument.
 // 
 // ***********************************************************************
-NA_EIDPROC
 inline Lng32 ones( ULng32 x )
 {
   unsigned char * px = (unsigned char *) &x;
@@ -1071,7 +1062,7 @@ public:
   // set heap after constructor has been called but before object is used
   void setHeap(CollHeap *heap);
 
-  NA_EIDPROC inline CollIndex resize( CollIndex newSize )
+  inline CollIndex resize( CollIndex newSize )
    {
    if (newSize > maxLength_)
       {
@@ -1131,10 +1122,10 @@ public:
     return( wordSize_ * BitsPerWord );
 	   }
 
-  NA_EIDPROC CollIndex getWordSize   () const { return( wordSize_ ); }
-  NA_EIDPROC CollIndex getLastStaleBit() const { return( lastStaleBit_ ); }
+  CollIndex getWordSize   () const { return( wordSize_ ); }
+  CollIndex getLastStaleBit() const { return( lastStaleBit_ ); }
 
-  NA_EIDPROC inline void extendWordSize( CollIndex minWordSize )
+  inline void extendWordSize( CollIndex minWordSize )
    {
    // resize the array
    resize( minWordSize );
@@ -1261,7 +1252,7 @@ public:
   // e.g. in a for-loop:  for(CollIndex i = 0; nextUsed(i); i++) ...
   // ---------------------------------------------------------------------
 
-  NA_EIDPROC inline NABoolean nextUsed( CollIndex & start ) const
+  inline NABoolean nextUsed( CollIndex & start ) const
    {
    CollIndex limit = wordSize_ << LogBitsPerWord;
 
@@ -1432,7 +1423,7 @@ public:
   NASubCollection<T> & intersectSet(const NASubCollection<T> & other);
   NASubCollection<T> & subtractSet(const NASubCollection<T> & other);
 
-  NA_EIDPROC inline NASubCollection<T> & addElement( CollIndex elem )
+  inline NASubCollection<T> & addElement( CollIndex elem )
   {
   CollIndex wordNumber = wordNo( elem );
 
@@ -1465,7 +1456,7 @@ public:
   // Fast path when elem is probably less than 64.  
   inline NASubCollection<T> & addElementFast(CollIndex elem);
   
-  NA_EIDPROC inline NASubCollection<T> & subtractElement( CollIndex elem )
+  inline NASubCollection<T> & subtractElement( CollIndex elem )
    {
    CollIndex wordNumber = wordNo( elem );
 
@@ -1600,7 +1591,7 @@ inline CollIndex NASubCollection<T>::prevUsed(CollIndex start) const
 
 // Returns the ordinal position of the last bit set in the uint64_t passed as
 // an argument.
-NA_EIDPROC inline ULng32 FindLastOne(uint64_t x)
+inline ULng32 FindLastOne(uint64_t x)
 {
   // Set bits right of, and clear bits left of, last bit set.
   uint64_t y = x ^ (x - 1);
@@ -1886,7 +1877,7 @@ public:
     { return NACollection<T>::getByteSize() + sizeof(*this) - 
         sizeof(NACollection<T>); }
 
-  NA_EIDPROC inline NABoolean insert(const T &elem)
+  inline NABoolean insert(const T &elem)
   {
     invalidateCache();
     if (NACollection<T>::find(elem) == NULL_COLL_INDEX)
@@ -1899,7 +1890,7 @@ public:
   }
 
   // A dumb but easy implementation for insert one SET into another
-  NA_EIDPROC inline NABoolean insert(const NASet<T> &other)
+  inline NABoolean insert(const NASet<T> &other)
   {
     CollIndex count = other.entries();
     for (CollIndex i = 0; i < count; i++)
@@ -1909,7 +1900,7 @@ public:
     return TRUE;
   } // insert(SET(T))
 
-  NA_EIDPROC inline NABoolean remove(const T &elem)
+  inline NABoolean remove(const T &elem)
   {
     CollIndex ix = NACollection<T>::find(elem);
 
@@ -1924,7 +1915,7 @@ public:
   }
 
   // A dumb but easy implementation for remove one SET from  another
-  NA_EIDPROC inline NABoolean remove(const NASet<T> &other)
+  inline NABoolean remove(const NASet<T> &other)
   {
     CollIndex count = this->entries();
     for (CollIndex i = 0; i < count; i++)
@@ -1969,7 +1960,7 @@ public:
   }
 
   // virtual destructor
-  NA_EIDPROC virtual ~NAList();
+  virtual ~NAList();
 
   // assignment
   
@@ -1984,7 +1975,7 @@ public:
   // insert a set, array, or list
   // void insert(const SET(T) &other);
 
-  NA_EIDPROC void insert(const LIST(T) &other);
+  void insert(const LIST(T) &other);
 
   // remove an element(the first that matches) that is given by its value
   //(returns whether the element was found and removed)
@@ -2013,7 +2004,7 @@ public:
   { return(NACollection<T>::find(elem) != NULL_COLL_INDEX); }
 
   // find a given element in the collection and return it
-  NA_EIDPROC NABoolean find(const T &elem, T &returnedElem) const;
+  NABoolean find(const T &elem, T &returnedElem) const;
 
   // find the index of a given element or return NULL_COLL_INDEX if not found
   inline CollIndex index (const T &elem) const
@@ -2038,7 +2029,7 @@ public:
   }
 
   // index access(both reference and value), zero based
-  NA_EIDPROC T & operator [](CollIndex i);
+  T & operator [](CollIndex i);
   const T & operator [](CollIndex i) const;
 
   inline T & at(CollIndex i) { return operator [](i); }
@@ -2059,7 +2050,7 @@ public:
 
   // remove the index'th element from the list
   //(returns TRUE if list[index] was found, FALSE if index was out of bounds)
-  NA_EIDPROC inline NABoolean removeAt(const CollIndex index)
+  inline NABoolean removeAt(const CollIndex index)
   {
     // check whether index is legal
     if (index >= this->entries())
@@ -2102,7 +2093,7 @@ public:
   // insert a new entry at a given position(new element becomes element # i,
   // the rest of the list moves 1 entry up)
   // use i = entries() to insert at the end, i = 0 to insert at the front
-  NA_EIDPROC inline CollIndex insertAt(CollIndex i, const T &elem)
+  inline CollIndex insertAt(CollIndex i, const T &elem)
   {
     CollIndex newIndex = this->freePos();
     CollIndex newUsage;
@@ -2157,7 +2148,7 @@ public:
   // remove the first entry from the list and store it in "elem"
   //(returns FALSE if the list is empty and no value is returned)
 
-  NA_EIDPROC inline NABoolean getFirst(T &elem)
+  inline NABoolean getFirst(T &elem)
   {
     if (this->entries() > 0)
     {
@@ -2590,7 +2581,6 @@ friend class NAHashDictionaryIterator<K,V>;
   // --------------------------------------------------------------------
   // Constructor functions.
   // --------------------------------------------------------------------
-//#if defined(NA_UNIX) && !defined(NA_LINUX) 
   // Previously the code was ugly -- it used a hash function that was defined
   // in the scope of the file using the NAHashDictionary template. New 
   // compilers produce an error ("undeclared variable" ) in case the template
@@ -2703,14 +2693,12 @@ private:
 
 private: 
 
-//#if !defined(NA_UNIX) || defined(NA_LINUX)
   // Needed only for the old way of NAHashDictionary -- see comment above
   // --------------------------------------------------------------------
   // The hash function that is applied to the key for determining the 
   // bucket to which it belongs.				  
   // --------------------------------------------------------------------
   ULng32(*hash_)(const K&);
-//#endif
   
   // --------------------------------------------------------------------
   // The hash table is an array of hash buckets.

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComASSERT.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComASSERT.h b/core/sql/common/ComASSERT.h
index bf56bdf..713fc3d 100644
--- a/core/sql/common/ComASSERT.h
+++ b/core/sql/common/ComASSERT.h
@@ -41,13 +41,13 @@
 // macro ComASSERT does nothing.
 // -----------------------------------------------------------------------
 
-#if defined(NDEBUG) || defined(NA_NO_C_RUNTIME)
+#if defined(NDEBUG)
   #define ComASSERT(ex)
 #else
   #define ComASSERT(ex) { if (!(ex)) NAAssert("" # ex "", __FILE__, __LINE__); }
 #endif
 
-#if defined(NDEBUG) || defined(__EID)
+#if defined(NDEBUG)
   #define ComDEBUG(ex)
   // An ABORT macro is defined in BaseTypes.h specifically for EID; must be used
   //#define ComABORT(ex){ if (!(ex)) NAAbort(__FILE__, __LINE__, "" # ex ""); }

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComAnsiNamePart.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComAnsiNamePart.h b/core/sql/common/ComAnsiNamePart.h
index a8e5ad0..a655908 100644
--- a/core/sql/common/ComAnsiNamePart.h
+++ b/core/sql/common/ComAnsiNamePart.h
@@ -245,7 +245,7 @@ class ComAnsiNamePart : public NABasicObject
     //
     NABoolean operator== (const ComAnsiNamePart &rhs) const;
 
-    NA_EIDPROC inline Int32      compareTo  (const ComAnsiNamePart &rhs) const;
+    inline Int32      compareTo  (const ComAnsiNamePart &rhs) const;
 
     //
     // accessors
@@ -375,7 +375,6 @@ class ComAnsiNamePart : public NABasicObject
 // definitions of inline methods
 // -----------------------------------------------------------------------
 
-NA_EIDPROC
 Int32 ComAnsiNamePart::compareTo (const ComAnsiNamePart &rhs) const
 {
   if (this EQU &rhs) return 0;

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComCextMisc.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComCextMisc.cpp b/core/sql/common/ComCextMisc.cpp
index b67901b..93b9037 100644
--- a/core/sql/common/ComCextMisc.cpp
+++ b/core/sql/common/ComCextMisc.cpp
@@ -1228,13 +1228,8 @@ extern "C"
 DLLEXPORT
 int_16 PROCESSHANDLE_DECOMPOSE_
   (int_16        *prochand, // INPUT
-#ifdef SQ_NEW_PHANDLE
    int        *cpu, // OUTPUT
    int        *pin, // OUTPUT
-#else
-   int_16        *cpu, // OUTPUT
-   int_16        *pin, // OUTPUT
-#endif // SQ_NEW_PHANDLE
    int_32        *node,     // OUTPUT  THE NODE NUMBER
    unsigned_char *nn,       // OUTPUT  NODE NAME
    int_16         nnml,     // INPUT   MAXIMUM OUTPUT LENGTH
@@ -1244,14 +1239,9 @@ int_16 PROCESSHANDLE_DECOMPOSE_
    int_16        *nl,       // OUTPUT
    fixed_0       *seq )
 {
-#ifdef SQ_NEW_PHANDLE
    PNSK_PORT_HANDLE    phandle = (PNSK_PORT_HANDLE)prochand;
    return XPROCESSHANDLE_DECOMPOSE_(phandle, cpu, pin, node, (char *)nn,
                                     nnml, nnl, (char *)name, nml, nl, seq);
-#else
-   return XPROCESSHANDLE_DECOMPOSE_(prochand, cpu, pin, node, (char *)nn,
-                                    nnml, nnl, (char *)name, nml, nl, seq);
-#endif // SQ_NEW_PHANDLE
 }
 
 extern "C"

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComDistribution.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComDistribution.h b/core/sql/common/ComDistribution.h
index 61dad33..a3a1e6f 100644
--- a/core/sql/common/ComDistribution.h
+++ b/core/sql/common/ComDistribution.h
@@ -39,10 +39,8 @@
 #include "NABoolean.h"
 #include "ComSizeDefs.h"
 #include "ComCharSetDefs.h"
-#if !defined (ARKFS_OPEN) 
-  #include "ComDiags.h"
-  #include "ComSmallDefs.h"
-#endif
+#include "ComDiags.h"
+#include "ComSmallDefs.h"
 
   #ifndef __DERROR__
     #include "fs/feerrors.h"
@@ -307,8 +305,6 @@ void ComFeatureVersionInfoSPInputTypeToLiteral ( const FeatureVersionInfoSPInput
 FeatureVersionInfoSPInputType ComFeatureVersionInfoSPLiteralToInputType 
                                                ( const char * inputTypeLiteral );
 
-
-#if !defined (ARKFS_OPEN) 
 //----------------------------------------------------------------------
 //
 //  Translate an anchor file access error to something more sensible.
@@ -352,9 +348,7 @@ private:
 //         objects survive the table name's allocation.
 //
 //     NB: Metadata access through DDOL will not use this class in R2.0. That is,
-//         utilities will not perform the SMD table error translation. The RFork
-//         error translation is done by the DDL layer, utilities that access RForks 
-//         using classes from DDL will see RFork access error translation.
+//         utilities will not perform the SMD table error translation.
 //
 class MetaDataErrorTranslator : public ComDiagsTranslator
 {
@@ -409,8 +403,6 @@ private:
 
 };
 
-#endif
-
 //----------------------------------------------------------------------
 //
 //  Handy defines, to convert between different string formats (fix length&space filled vs. zero-terminated)

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComMPLoc.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComMPLoc.h b/core/sql/common/ComMPLoc.h
index b3483e2..65d444a 100644
--- a/core/sql/common/ComMPLoc.h
+++ b/core/sql/common/ComMPLoc.h
@@ -46,16 +46,16 @@
 #include "ComSmallDefs.h"
 #include "Platform.h"
 
-NA_EIDPROC inline ComBoolean  IsMPLocPrefix(const char c)
+inline ComBoolean  IsMPLocPrefix(const char c)
   { return c == '$' || c == '\\'; }
 
-NA_EIDPROC inline ComBoolean  IsMPLocPrefix(const unsigned char c)
+inline ComBoolean  IsMPLocPrefix(const unsigned char c)
   { return c == '$' || c == '\\'; }
 
-NA_EIDPROC inline ComBoolean  HasMPLocPrefix(const char *s)
+inline ComBoolean  HasMPLocPrefix(const char *s)
   { return IsMPLocPrefix(*s); }
 
-NA_EIDPROC inline const char *ChopMPLocPrefix(const char *s)
+inline const char *ChopMPLocPrefix(const char *s)
   { return HasMPLocPrefix(s) ? &s[1] : s; }
 
 // Max length of an externally formatted name

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComObjectName.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComObjectName.cpp b/core/sql/common/ComObjectName.cpp
index d34cb0c..9307d75 100644
--- a/core/sql/common/ComObjectName.cpp
+++ b/core/sql/common/ComObjectName.cpp
@@ -783,36 +783,6 @@ ComObjectName::scan( const NAString &externalObjectName
   size_t trailingJunkIsOk = bytesScanned;
   bytesScanned = 0;
 
-  if (( SqlParser_Initialized() && SqlParser_NAMETYPE == DF_NSK)       ||
-      //(ComRtIsNSKName((char *)externalObjectName.data()))            ||
-      //(*externalObjectName.data() == '\$') ) {
-      (!SqlParser_Initialized() && *externalObjectName.data() == '\\')) {
-
-    NAString nam(externalObjectName);
-    size_t b = externalObjectNameLen;
-
-    if (trailingJunkIsOk) {
-      #define LEGAL_PUNCTUATION		" \t,();"
-      size_t j = strcspn(externalObjectName, LEGAL_PUNCTUATION);
-      if (j < b) {
-        b = j;
-        nam.remove(b);
-      }
-    }
-
-    // Is this a valid 1, 2, 3, or 4-part NSK filename?
-    ComMPLoc loc(nam, ComMPLoc::FILE);
-    if (loc.isValid(ComMPLoc::FILE)) {
-      #define COPY_VALIDATED_STRING(x)		\
-   		 ComAnsiNamePart(x, ComAnsiNamePart::INTERNAL_FORMAT)
-      catalogNamePart_ = COPY_VALIDATED_STRING(loc.getSysDotVol());
-      schemaNamePart_  = COPY_VALIDATED_STRING(loc.getSubvolName());
-      objectNamePart_  = COPY_VALIDATED_STRING(loc.getFileName());
-      bytesScanned = b;
-      return TRUE;
-    }
-  } // end of if (( SqlParser_Initialized()  ...
-
   // ---------------------------------------------------------------------
   // Scan the leftmost ANSI SQL name part.
   // ---------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComRtUtils.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComRtUtils.cpp b/core/sql/common/ComRtUtils.cpp
index e82c23c..217bf08 100644
--- a/core/sql/common/ComRtUtils.cpp
+++ b/core/sql/common/ComRtUtils.cpp
@@ -92,7 +92,6 @@ static const ModName internalSystemSchemaModNameList[] = {
   ,{"CMSMDIOWRITEM_N29_000"} 
   ,{"MVQR_N29_000"} 
   ,{"READDEF_N29_000"} 
-  ,{"RFORK_N29_000"} 
   ,{"SQLHIST_N29_000"} 
   ,{"SQLUTILS_N29_000"} 
   ,{"HP_ROUTINES_N29_000"} 
@@ -516,7 +515,7 @@ const char * ComRtGetEnvValueFromEnvvars(const char ** envvars,
   return NULL;
 }
 
-#if defined (_DEBUG) && !defined (ARKFS_OPEN) && !defined (__EID)
+#if defined (_DEBUG)
 // -----------------------------------------------------------------------
 // Convenient handling of envvars: Return a value if one exists
 // NB: DEBUG mode only!
@@ -706,9 +705,7 @@ Lng32 ComRtGetProgramInfo(char * pathName,    /* out */
 			 Int64  &processCreateTime,
 			 char *processNameString,
 			 char *parentProcessNameString
-#ifdef SQ_PHANDLE_VERIFIER
                          , SB_Verif_Type *verifier
-#endif
 )
 {
   Lng32 retcode = 0;
@@ -721,10 +718,8 @@ Lng32 ComRtGetProgramInfo(char * pathName,    /* out */
   myPhandle.decompose();
   cpu = myPhandle.getCpu();
   pin = myPhandle.getPin();
-#ifdef SQ_PHANDLE_VERIFIER
   if (verifier)
     *verifier = myPhandle.getSeqNum();
-#endif
 
   // Map the node number to cpu
   nodeNumber = cpu;

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComRtUtils.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComRtUtils.h b/core/sql/common/ComRtUtils.h
index 165b6b4..3f7e4f7 100644
--- a/core/sql/common/ComRtUtils.h
+++ b/core/sql/common/ComRtUtils.h
@@ -45,12 +45,9 @@
 #include <fstream>
 using namespace std;
 #include "seabed/ms.h"
-#ifdef NA_64BIT
-// dg64 - the following includes defines min
 #ifdef min
 #undef min
 #endif // min
-#endif // NA_64BIT
 
 #define MAX_SEGMENT_NAME_LEN  255
 #define PROCESSNAME_STRING_LEN    40
@@ -189,9 +186,7 @@ Lng32 ComRtGetProgramInfo(char * pathName,    /* out */
 			 Int64  &processCreateTime,
 			  char *processNameString,
 			  char *parentProcessNameString = NULL
-#ifdef SQ_PHANDLE_VERIFIER
                          , SB_Verif_Type *verifier = NULL
-#endif
 			 );
 
 // OUT: processPriority: current priority of process
@@ -226,7 +221,7 @@ const char * ComRtGetEnvValueFromEnvvars(const char ** envvars,
 					 const char * envvar,
 					 Lng32 * envvarPos = NULL);
 
-#if defined (_DEBUG) && !defined (ARKFS_OPEN) && !defined (__EID)
+#if defined (_DEBUG)
 // -----------------------------------------------------------------------
 // Convenient handling of envvars: Return a value if one exists
 // NB: DEBUG mode only!

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSafePrinter.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSafePrinter.cpp b/core/sql/common/ComSafePrinter.cpp
index b382423..a40fb3f 100644
--- a/core/sql/common/ComSafePrinter.cpp
+++ b/core/sql/common/ComSafePrinter.cpp
@@ -69,7 +69,7 @@ Int32 ComSafePrinter::vsnPrintf(char *str, size_t n,
   if (!outfile_)
   {
     outfile_ = tmpfile();
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
     if (!outfile_)
     {
       fprintf(stderr,

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSchemaName.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSchemaName.cpp b/core/sql/common/ComSchemaName.cpp
index 0618daa..772aa64 100644
--- a/core/sql/common/ComSchemaName.cpp
+++ b/core/sql/common/ComSchemaName.cpp
@@ -217,29 +217,6 @@ ComSchemaName::scan(const NAString &externalSchemaName,
   size_t externalSchemaNameLen = externalSchemaName.length();
   bytesScanned = 0;
 
-  #define COPY_VALIDATED_STRING(x)	\
-		      ComAnsiNamePart(x, ComAnsiNamePart::INTERNAL_FORMAT)
-
-  if (( SqlParser_Initialized() && SqlParser_NAMETYPE == DF_NSK)       ||
-      (!SqlParser_Initialized() && *externalSchemaName.data() == '\\')) {
-    ComMPLoc loc(externalSchemaName);
-    switch (loc.getFormat()) {
-      case ComMPLoc::SUBVOL:
-		catalogNamePart_ = COPY_VALIDATED_STRING(loc.getSysDotVol());
-		schemaNamePart_  = COPY_VALIDATED_STRING(loc.getSubvolName());
-		bytesScanned = externalSchemaNameLen;
-		return TRUE;
-
-      case ComMPLoc::FILE:
-		if (!loc.hasSubvolName()) {
-		  catalogNamePart_ = "";
-		  schemaNamePart_  = COPY_VALIDATED_STRING(loc.getFileName());
-		  bytesScanned = externalSchemaNameLen;
-		  return TRUE;
-		}
-    }
-  }
-
   // Each ComAnsiNamePart ctor below must be preceded by "count = 0;"
   // -- see ComAnsiNamePart.cpp, and for a better scan implementation,
   //    see ComObjectName::scan() + ComObjectName(bytesScanned) ctor.

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSmallDefs.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSmallDefs.cpp b/core/sql/common/ComSmallDefs.cpp
index 09211af..7986305 100644
--- a/core/sql/common/ComSmallDefs.cpp
+++ b/core/sql/common/ComSmallDefs.cpp
@@ -68,16 +68,7 @@
 // This function now for non-NSKLite platforms only (UNIX)
 Int64 ComSmallDef_local_GetTimeStamp(void)
 {
-  //#if defined(NA_HSC_LINUX) || defined(NA_LINUX)
-#if defined(NA_HSC_LINUX)
-  struct timeval tv;
-  gettimeofday(&tv, NULL);
-  return(Int64(tv.tv_usec) + (Int64(tv.tv_sec)*Int64(1000000L)));
-
-#else
   return(JULIANTIMESTAMP());
-
-#endif
 }
 
 

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSpace.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSpace.cpp b/core/sql/common/ComSpace.cpp
index 693cf25..12f2e87 100644
--- a/core/sql/common/ComSpace.cpp
+++ b/core/sql/common/ComSpace.cpp
@@ -47,16 +47,11 @@ extern ostream *TraceFile;
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef __EID
-  #include "ExeDp2.h"
-#endif
-
 #include "ComASSERT.h"
 #include "ComSpace.h"
 #include "str.h"
 #include "HeapLog.h"
 
-NA_EIDPROC
 void * operator new(size_t size, Space *s)
 {
   if (s)
@@ -87,7 +82,6 @@ ComSpace::ComSpace(SpaceType type, NABoolean fillUp, char *name)
   allocSize_ = 0;
 }
 
-NA_EIDPROC
 ComSpace::~ComSpace()
 {
   destroy();
@@ -101,9 +95,8 @@ void Space::setType(SpaceType type, Lng32 initialSize)
 
 void Space::setParent(CollHeap * parent) {
   // make sure that we haven't allocated anything yet. If something
-  // is already allocated, we do not set parent_!! Also, parent_
-  // is not set for DP2_SPACE
-  if ((allocSize_) || (type_ == DP2_SPACE))
+  // is already allocated, we do not set parent_.
+  if (allocSize_)
     return;
 
   parent_ = parent;
@@ -119,7 +112,6 @@ void Space::freeBlocks(void) {
   // free up all the blocks attached to this space pointer.
   Block * currBlock = firstBlock_;
   switch (type_) {
-  case DP2_SPACE:
   case SINGLE_BLOCK_SPACE:
     break;
 
@@ -162,10 +154,6 @@ Lng32 Space::defaultBlockSize(SpaceType type)
   // use default size
   switch (type)
     {
-    case DP2_SPACE:
-      //      block_size = DP2_BLOCK_MAX_SIZE;
-      block_size = 32768;
-      break;
     case EXECUTOR_SPACE:
     case GENERATOR_SPACE:
     case SYSTEM_SPACE:
@@ -181,7 +169,7 @@ Lng32 Space::defaultBlockSize(SpaceType type)
 
 // Round up input value to nearest multiple of 8.
 //
-NA_EIDPROC static Lng32 roundUp8(Lng32 val)
+static Lng32 roundUp8(Lng32 val)
 {
   ULng32 uval = (ULng32) val;
 
@@ -262,32 +250,6 @@ Block * Space::allocateBlock(SpaceType type,
   }
   else {
     switch (type) {
-    case DP2_SPACE: {
-#ifdef __EID
-      short rc;
-      void * memaddr = 0;
-
-      rc = DP2_EXECUTOR_ADD_MEMORY (block_size, &memaddr);
-
-      //fprintf(stdout,"alloc %d bytes, retcode %d, memaddr %d\n",
-      //        block_size, rc, memaddr);
-      //fflush(stdout);
-
-      // if the allocation failed, return NULL
-      if (rc != FEOK)
-	return NULL;
-
-#ifdef TRACE_DP2_MALLOCS
-      *TraceFile << "DP2_EXECUTOR_ADD_MEMORY alloc'd " << block_size
-		 << " bytes at " << (void *) memaddr
-		 << " which the executor will use as a Space block." << endl;
-#endif
-
-      block_ptr = (char *)memaddr;
-#endif
-    }
-    break;
-
     case EXECUTOR_SPACE:
     case GENERATOR_SPACE:
     case SYSTEM_SPACE: {
@@ -344,9 +306,7 @@ char *Space::privateAllocateSpace(ULng32 size, NABoolean failureIsFatal) {
       // we do something special in firstAllocation
       const NABoolean firstAllocation = TRUE ;
       firstBlock_ = lastBlock_ = searchList_ =
-#pragma nowarn(1506)   // warning elimination
         allocateBlock(type_, size, firstAllocation, NULL, failureIsFatal);
-#pragma warn(1506)  // warning elimination
     }
 
   if (firstBlock_ == NULL)
@@ -387,9 +347,7 @@ char *Space::privateAllocateSpace(ULng32 size, NABoolean failureIsFatal) {
     // space not found in any existing block.
     // Allocate a new one and append it to the last block.
     // The minimum space allocated in a block is max size for 'type'.
-#pragma nowarn(1506)   // warning elimination
       currBlock = allocateBlock(type_, size, FALSE, NULL, failureIsFatal);
-#pragma warn(1506)  // warning elimination
 
       // return if we couldn't allocate a block
       if (currBlock == NULL)
@@ -424,9 +382,7 @@ char *Space::privateAllocateSpace(ULng32 size, NABoolean failureIsFatal) {
 
 void * Space::allocateSpaceMemory(size_t size, NABoolean failureIsFatal) {
       void * rc = allocateAlignedSpace(size, failureIsFatal);
-#pragma nowarn(1506)   // warning elimination
       HEAPLOG_ADD_ENTRY(rc, size, heapID_.heapNum, getName())
-#pragma warn(1506)  // warning elimination
       if (rc) return rc;
       if (failureIsFatal && size > 0)
         {
@@ -477,39 +433,21 @@ char *Space::allocateAndCopyToAlignedSpace(const char *dp,
 	break;
     case sizeof(char):
 	ComASSERT(dlen <= UCHAR_MAX)
-#pragma nowarn(1506)   // warning elimination
 	*(char *)rp = dlen;
-#pragma warn(1506)  // warning elimination
 	break;
     case sizeof(short):
 	ComASSERT(dlen <= USHRT_MAX)
-#pragma nowarn(1506)   // warning elimination
 	*(short *)rp = dlen;
-#pragma warn(1506)  // warning elimination
 	break;
-#ifdef NA_64BIT
-    // dg64 - a bit of a guess
     case sizeof(Int32):
 	ComASSERT(dlen <= UINT_MAX)
-#pragma nowarn(1506)   // warning elimination 
 	*(Int32 *)rp = dlen;
-#pragma warn(1506)  // warning elimination 
 	break;
-#else
-    case sizeof(Lng32):
-	ComASSERT(dlen <= ULONG_MAX)
-#pragma nowarn(1506)   // warning elimination
-	*(Lng32 *)rp = dlen;
-#pragma warn(1506)  // warning elimination
-	break;
-#endif
     default:
 	ComASSERT(0==1);
   }
   char* rdp = rp + countPrefixSize;
-#pragma nowarn(1506)   // warning elimination
   str_cpy_all(rdp, dp, dlen);
-#pragma warn(1506)  // warning elimination
   if ((countPrefixSize == 0) && (NOT noSizeAdjustment))
     rdp[dlen] = '\0';
 
@@ -625,9 +563,7 @@ void* Space::convertToPtr(Long offset) const
 Lng32 Space::allocAndCopy(void * from, ULng32 size, NABoolean failureIsFatal)
 {
   char * to = allocateAlignedSpace(size, failureIsFatal);
-#pragma nowarn(1506)   // warning elimination
   str_cpy_all(to, (char *)from, size);
-#pragma warn(1506)  // warning elimination
   return (convertToOffset(to));
 }
 // LCOV_EXCL_STOP
@@ -678,9 +614,8 @@ char * Space::makeContiguous(char * out_buf, ULng32 out_buflen)
   return out_buf;
 }
 
-#if (defined(_DEBUG) || defined(NSK_MEMDEBUG)) && !defined(__EID) && !defined(STAND_ALONE)
+#if (defined(_DEBUG) || defined(NSK_MEMDEBUG))
 
-// LCOV_EXCL_START
 void Space::dumpSpaceInfo(ostream* outstream, Lng32 indent) {
   char ind[100];
   Lng32 indIdx = 0;
@@ -691,9 +626,6 @@ void Space::dumpSpaceInfo(ostream* outstream, Lng32 indent) {
     outstream = &cerr;
   *outstream << ind << "Dump of Space: " << this << " (";
   switch (type_) {
-  case DP2_SPACE:
-    *outstream << "DP2_SPACE";
-    break;
   case EXECUTOR_SPACE:
     *outstream << "EXECUTOR_SPACE";
       break;
@@ -710,7 +642,6 @@ void Space::dumpSpaceInfo(ostream* outstream, Lng32 indent) {
 	     << ind << "Total Allocated Size (Bytes): " << allocSize_ << endl;
 
 }
-// LCOV_EXCL_STOP
 #endif
 
 /////////////////////////////////////////////

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSpace.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSpace.h b/core/sql/common/ComSpace.h
index 5de6565..4965c70 100644
--- a/core/sql/common/ComSpace.h
+++ b/core/sql/common/ComSpace.h
@@ -63,9 +63,8 @@ typedef class ComSpace : public CollHeap {
 public:
   enum SpaceType
     {
-      DP2_SPACE,             // executor in DP2
       EXECUTOR_SPACE,        // master executor and ESPs
-      GENERATOR_SPACE,       // arkcmp, used to generate module files and rfork
+      GENERATOR_SPACE,       // arkcmp, used to generate module file
       SYSTEM_SPACE,
       SINGLE_BLOCK_SPACE
     };
@@ -77,12 +76,6 @@ private:
   // recommended/default size for block. Caller can allocate
   // a different size, though, and pass that to
   // the init method.
-  enum BlockSize
-    { DP2_BLOCK_MAX_SIZE = 100000
-      // EXECUTOR_BLOCK_MAX_SIZE = 131072,
-      // SYSTEM_BLOCK_MAX_SIZE = 10240
-    };
-
   SpaceType type_;
 
   // if this space is an EXECUTOR_SPACE or SYSTEM_SPACE, it is
@@ -111,12 +104,10 @@ private:
                       // this.
   // don't call this directly, as allocateAlignedSpace() won't work
   // if some of the requests are for non-aligned space
-NA_EIDPROC
   char * privateAllocateSpace(ULng32 size, NABoolean failureIsFatal = TRUE);
 
   // allocate a block of the indicated length (must be a multiple
   // of 8)
-NA_EIDPROC
   Block * allocateBlock(SpaceType type,
                         Lng32 in_block_size = 0,
                         NABoolean firstAllocation = FALSE,
@@ -124,31 +115,22 @@ NA_EIDPROC
 			NABoolean failureIsFatal = TRUE);
 
 public:
-NA_EIDPROC
   ComSpace(SpaceType type = SYSTEM_SPACE, NABoolean fillUp = TRUE, char *name = NULL);
-NA_EIDPROC
   void destroy();
 
-NA_EIDPROC
   ~ComSpace();
 
 
-NA_EIDPROC
   void freeBlocks(void);
 
-NA_EIDPROC
   void setType(SpaceType type, Lng32 initialSize = 0);
 
-NA_EIDPROC
   void setFirstBlock(char * blockAddr, Lng32 blockLen, NABoolean failureIsFatal = TRUE);
 
-NA_EIDPROC
   void setParent(CollHeap * parent);
 
-NA_EIDPROC
   char * allocateAlignedSpace(ULng32 size, NABoolean failureIsFatal = TRUE);
 
-NA_EIDPROC
   char * allocateAndCopyToAlignedSpace(const char* dp,
 				       size_t dlen,
 				       size_t countPrefixSize = 0,
@@ -156,63 +138,45 @@ NA_EIDPROC
 				       NABoolean noSizeAdjustment = FALSE);
 
   // returns total space allocated size (space allocated by the user)
-NA_EIDPROC
   inline Lng32 getAllocatedSpaceSize(){
     return allocSize_;
   }
 
-NA_EIDPROC
   void * allocateSpaceMemory(size_t size, NABoolean failureIsFatal = TRUE);
 
-NA_EIDPROC
   void deallocateSpaceMemory(void *)
   { /* no op */ };
 
-NA_EIDPROC
   Long convertToOffset(void *);
 
-NA_EIDPROC
   void* convertToPtr(Long offset) const;
 
-NA_EIDPROC
   Lng32 allocAndCopy(void *, ULng32, NABoolean failureIsFatal = TRUE);
 
-NA_EIDPROC
   short isOffset(void *);
 
-NA_EIDPROC
   NABoolean isOverlappingMyBlocks(char * buf, ULng32 size);
 
   // moves all the Blocks into the output contiguous buffer.
-NA_EIDPROC
   char * makeContiguous(char * out_buf, ULng32 out_buflen);
 
-#if (defined(_DEBUG) || defined(NSK_MEMDEBUG)) && !defined(__EID) && !defined(STAND_ALONE)
-NA_EIDPROC
+#if (defined(_DEBUG) || defined(NSK_MEMDEBUG))
   void dumpSpaceInfo(ostream *outstream, Lng32 indent);
 #endif
 
-NA_EIDPROC
   static void outputBuffer(ComSpace * space, char * buf, char * newbuf);
 
-NA_EIDPROC
   static void display(char *buf, size_t buflen,
 		      size_t countPrefixSize, ostream &outstream);
 
-NA_EIDPROC
   static Lng32 defaultBlockSize(SpaceType type);
 
 NABoolean outputbuf_; // set to false until we use the buffer for output
 
 } Space;
 
-NA_EIDPROC
 void * operator new(size_t size, ComSpace *s);
 
-#ifndef ARKFS_OPEN
-#endif // !ARKFS_OPEN
-
-
 /////////////////////////////////////////////
 //
 // class Block
@@ -241,41 +205,29 @@ class Block {
 
 public:
 
-NA_EIDPROC
   void init(Lng32 block_size, Lng32 data_size, char * data_ptr);
 
   // allocate 'size' amount of space in this block
-NA_EIDPROC
   char *allocateMemory(ULng32 size);
 
-NA_EIDPROC
   NABoolean isOverlapping(char * buf, ULng32 size);
 
-NA_EIDPROC
   inline Lng32 getAllocatedSize(){return allocatedSize_;};
 
-NA_EIDPROC
   inline Block *getNext(){return nextBlock_;};
 
-NA_EIDPROC
   inline Lng32 getFreeSpace(){return freeSpaceSize_;};
 
-NA_EIDPROC
   inline Lng32 getBlockSize(){return blockSize_;};
 
-NA_EIDPROC
   inline Block *getNextSearch(){return nextSearchBlock_;};
 
-NA_EIDPROC
   inline void setNext(Block *b){nextBlock_ = b;};
 
-NA_EIDPROC
   inline void setNextSearch(Block* b){nextSearchBlock_ = b;};
 
-NA_EIDPROC
   inline char * getDataPtr(){return dataPtr_;};
 
-NA_EIDPROC
   inline Lng32 getMaxSize(){return maxSize_;};
 };
 

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSqlId.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSqlId.h b/core/sql/common/ComSqlId.h
index 80e70ed..8d0abc7 100644
--- a/core/sql/common/ComSqlId.h
+++ b/core/sql/common/ComSqlId.h
@@ -143,7 +143,7 @@ public:
   { 
     MIN_SESSION_ID_LEN = 
     PREFIX_LEN + VERSION_LEN + SEGMENT_LEN +
-// in case NA_LINUX Cpu and Segment number are at the same location
+    // in case Cpu and Segment number are at the same location
     PIN_LEN + STARTTS_LEN + SESSIONNUM_LEN + USERNAMELEN_LEN +
     SESSIONNAMELEN_LEN
   };
@@ -184,10 +184,10 @@ public:
     USERNAME_OFFSET    = USERNAMELEN_OFFSET + USERNAMELEN_LEN
   };
     
-NA_EIDPROC    
+   
   ComSqlId(CollHeap * heap);
 
-NA_EIDPROC    
+   
   static Lng32 getSqlQueryIdAttr
    (Lng32 attr,         // which attr (SqlQueryIDAttr)
     char * queryId,    // query ID
@@ -198,7 +198,7 @@ NA_EIDPROC
                        // the returned value.
     char * stringValue); // null terminated returned value for string attrs.
 
-NA_EIDPROC    
+   
   static Lng32 getSqlSessionIdAttr
    (Lng32 attr,         // which attr (SqlQueryIDAttr)
     char * queryId,    // query ID
@@ -210,7 +210,7 @@ NA_EIDPROC
     char * stringValue); // null terminated returned value for string attrs.
 
 
-NA_EIDPROC    
+   
   static Lng32 createSqlSessionId
   (char * sessionId,            // INOUT
    Lng32 maxSessionIdLen,       // IN
@@ -226,7 +226,7 @@ NA_EIDPROC
    const char *userSessionName  // IN
    );
    
-NA_EIDPROC    
+   
   static Lng32 createSqlQueryId
   (char * queryId,           // INOUT
    Lng32 maxQueryIdLen,       // IN
@@ -238,7 +238,7 @@ NA_EIDPROC
    char * queryName          // IN
    );
 
-NA_EIDPROC    
+   
   static Lng32 extractSqlSessionIdAttrs
   (const char * sessionId,       // IN
    Lng32 sessionIdLen,        // IN
@@ -255,7 +255,7 @@ NA_EIDPROC
    );
 
   // returns a compact form of query id which is shipped to dp2.
-NA_EIDPROC    
+   
   static Lng32 getDp2QueryIdString
   (char * queryId,
    Lng32 queryIdLen,
@@ -263,7 +263,6 @@ NA_EIDPROC
    Lng32 &dp2QueryIdLen
    );
 
-NA_EIDPROC
   static Lng32 decomposeDp2QueryIdString
   (char * queryId,                    // input: buffer containing dp2 query id
    Lng32 queryIdLen,                   // input: length of query id
@@ -276,7 +275,7 @@ NA_EIDPROC
    );
 
 private:
-  NA_EIDPROC    
+     
   static Lng32 getSqlIdAttr
    (Lng32 attr,         // which attr (SqlQueryIDAttr)
     const char * queryId,// query ID

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSysUtils.cpp
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSysUtils.cpp b/core/sql/common/ComSysUtils.cpp
index 38bbcd2..957ee51 100644
--- a/core/sql/common/ComSysUtils.cpp
+++ b/core/sql/common/ComSysUtils.cpp
@@ -80,7 +80,6 @@
 // ****************************************************************************
 
 extern "C" {
-NA_EIDPROC
 Int32 NA_gettimeofday(struct NA_timeval *tp, struct NA_timezone *tzp)
   {
     return gettimeofday(tp, 0);

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComSysUtils.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComSysUtils.h b/core/sql/common/ComSysUtils.h
index 8f786e4..341851a 100644
--- a/core/sql/common/ComSysUtils.h
+++ b/core/sql/common/ComSysUtils.h
@@ -150,26 +150,19 @@ inline UInt64 reversebytes( UInt64 xx )
     return sink.xx;
 }
 
-#ifdef NA_64BIT /* Needed when _int64 and Int64 don't resolve to same basic type */
-/*inline _int64 reversebytes( _int64 sometexianendian )
-{
-  return( (_int64) reversebytes( (Int64) sometexianendian ) );
-} */
-#endif
-
-#endif  // NA_LITTLE_ENDIAN and NA_WINNT
+#endif  // NA_LITTLE_ENDIAN
 //----------------------------------------------------------------
 
 #endif
 
-NA_EIDPROC 
+
 void copyInteger (void *destination, Int32 targetLength, 
 		  void *sourceAddress, Int32 sourceLength);
 
 void copyToInteger1 (Int8 *destination, void *sourceAddress, Int32 sourceSize);
-NA_EIDPROC 
+
 void copyToInteger2 (short *destination, void *sourceAddress, Int32 sourceSize);
-NA_EIDPROC 
+
 void copyToInteger4 (Lng32 *destination, void *sourceAddress, Int32 sourceSize);
-NA_EIDPROC 
+
 void copyToInteger8 (Int64 *destination, void *sourceAddress, Int32 sourceSize);

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/ComVersionDefs.h
----------------------------------------------------------------------
diff --git a/core/sql/common/ComVersionDefs.h b/core/sql/common/ComVersionDefs.h
index 09da278..4c11ce0 100644
--- a/core/sql/common/ComVersionDefs.h
+++ b/core/sql/common/ComVersionDefs.h
@@ -104,7 +104,7 @@ inline
 COM_VERSION  ComVersion_GetCurrentSchemaVersion (void) {return COM_VERS_CURR_SCHEMA;};
 inline  
 COM_VERSION  ComVersion_GetMXV (void) {return COM_VERS_MXV;};
-inline NA_EIDPROC
+inline
 COM_VERSION  ComVersion_GetCurrentPlanVersion (void) {return COM_VERS_CURR_PLAN;};
 
 //

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/DgBaseType.h
----------------------------------------------------------------------
diff --git a/core/sql/common/DgBaseType.h b/core/sql/common/DgBaseType.h
index a538205..721af8b 100644
--- a/core/sql/common/DgBaseType.h
+++ b/core/sql/common/DgBaseType.h
@@ -84,13 +84,13 @@ enum DGTYPE
 class DgBase
 {
 public:
-NA_EIDPROC 
+
   virtual DGTYPE getTypeName() const = 0;
 
 }; 
 
 
-NA_EIDPROC 
+
 ComDiagsArea& operator<<(ComDiagsArea&, const DgBase &);
 
 
@@ -106,13 +106,11 @@ class DgSqlCode : public DgBase
 {
 public:
   enum ErrorOrWarning { ERROR_ = -1, WARNING_ = +1 };
-NA_EIDPROC
   DgSqlCode   (Lng32   aSqlCode);
-NA_EIDPROC
   DgSqlCode   (Lng32   aSqlCode, ErrorOrWarning e);
-NA_EIDPROC 
+
   Lng32        getSQLCODE() const {return theSQLCODE_; }
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   Lng32        theSQLCODE_;
@@ -122,11 +120,11 @@ private:
 class DgColumnName : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgColumnName  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -136,11 +134,11 @@ private:
 class DgCustomSQLState : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgCustomSQLState  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -150,11 +148,11 @@ private:
 class DgCatalogName : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgCatalogName  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -164,11 +162,11 @@ private:
 class DgSchemaName : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgSchemaName  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -178,11 +176,11 @@ private:
 class DgTableName : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgTableName  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -192,11 +190,11 @@ private:
 class DgConstraintCatalog : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgConstraintCatalog  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -206,11 +204,11 @@ private:
 class DgConstraintSchema : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgConstraintSchema  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -220,11 +218,11 @@ private:
 class DgConstraintName : public DgBase
 {
 public:
-NA_EIDPROC 
+
   DgConstraintName  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -234,11 +232,11 @@ private:
 class DgRowNumber : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgRowNumber  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   Lng32 theLong_;
@@ -248,11 +246,8 @@ private:
 class DgTriggerCatalog : public DgBase
 {
 public:
-NA_EIDPROC
   DgTriggerCatalog  (const char * const);
-NA_EIDPROC
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -262,11 +257,8 @@ private:
 class DgTriggerSchema : public DgBase
 {
 public:
-NA_EIDPROC
   DgTriggerSchema  (const char * const);
-NA_EIDPROC
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -276,11 +268,8 @@ private:
 class DgTriggerName : public DgBase
 {
 public:
-NA_EIDPROC
   DgTriggerName  (const char * const);
-NA_EIDPROC
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -290,11 +279,11 @@ private:
 class DgNskCode : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgNskCode  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   Lng32 theLong_;
@@ -304,11 +293,11 @@ private:
 class DgString0 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgString0  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -318,11 +307,11 @@ private:
 class DgString1 : public DgBase 
 { 
 public:
-NA_EIDPROC 
+
   DgString1  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -332,11 +321,11 @@ private:
 class DgString2 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgString2  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -346,11 +335,11 @@ private:
 class DgString3 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgString3  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   const char * const theCharStr_;
@@ -360,11 +349,11 @@ private:
 class DgString4 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgString4  (const char * const);
-NA_EIDPROC 
+
   const char * getCharStr  () const {return theCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   const char * const theCharStr_;
@@ -375,11 +364,11 @@ private:
 class DgWString0 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgWString0  (const NAWchar* const x) : theWCharStr_(x) {};
-NA_EIDPROC 
+
   const NAWchar* getWCharStr  () const {return theWCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const { return DGWSTRING0; };
 private:
   const NAWchar* const theWCharStr_;
@@ -389,11 +378,11 @@ private:
 class DgWString1 : public DgBase 
 { 
 public:
-NA_EIDPROC 
+
   DgWString1  (const NAWchar* const x) : theWCharStr_(x) {};
-NA_EIDPROC 
+
   const NAWchar* getWCharStr  () const {return theWCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const { return DGWSTRING1; };
 private:
   const NAWchar* const theWCharStr_;
@@ -403,11 +392,11 @@ private:
 class DgWString2 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgWString2  (const NAWchar* const x) : theWCharStr_(x) {};
-NA_EIDPROC 
+
   const NAWchar* getWCharStr  () const {return theWCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const  { return DGWSTRING2; };
 private:
   const NAWchar* const theWCharStr_;
@@ -417,11 +406,11 @@ private:
 class DgWString3 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgWString3  (const NAWchar* const x) : theWCharStr_(x) {};
-NA_EIDPROC 
+
   const NAWchar* getWCharStr  () const {return theWCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const { return DGWSTRING3; };
 private:
   const NAWchar* const theWCharStr_;
@@ -431,11 +420,11 @@ private:
 class DgWString4 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgWString4  (const NAWchar* const x) : theWCharStr_(x) {};
-NA_EIDPROC 
+
   const NAWchar* getWCharStr  () const {return theWCharStr_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const { return DGWSTRING4; };
 private:
   const NAWchar* const theWCharStr_;
@@ -445,11 +434,11 @@ private:
 class DgInt0 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgInt0  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const;
 private:
   Lng32 theLong_;
@@ -459,11 +448,11 @@ private:
 class DgInt1 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgInt1  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   Lng32 theLong_;
@@ -473,11 +462,11 @@ private:
 class DgInt2 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgInt2  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   Lng32 theLong_;
@@ -487,11 +476,11 @@ private:
 class DgInt3 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgInt3  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   Lng32 theLong_;
@@ -501,11 +490,11 @@ private:
 class DgInt4 : public DgBase
 { 
 public:
-NA_EIDPROC 
+
   DgInt4  (Lng32);
-NA_EIDPROC 
+
   Lng32 getLong  () const {return theLong_; };
-NA_EIDPROC 
+
   DGTYPE      getTypeName() const ;
 private:
   Lng32 theLong_;

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/common/DllExportDefines.h
----------------------------------------------------------------------
diff --git a/core/sql/common/DllExportDefines.h b/core/sql/common/DllExportDefines.h
index e700690..178ea35 100644
--- a/core/sql/common/DllExportDefines.h
+++ b/core/sql/common/DllExportDefines.h
@@ -18,24 +18,3 @@
 // under the License.
 //
 // @@@ END COPYRIGHT @@@
-#ifndef DLL_EXPORT_DEFINES_H
-#define DLL_EXPORT_DEFINES_H
-
-#undef SQLCLI_LIB_FUNC
-
-#if (defined (CLI_DLL) && !defined (NA_NSK))
-	#ifdef SQLCLI_LIB
-		#define SQLCLI_LIB_FUNC __declspec( dllexport )
-	#else
-		#define SQLCLI_LIB_FUNC __declspec( dllimport )
-	#endif
-#else
-	#define SQLCLI_LIB_FUNC
-#endif
-#ifdef NA_64BIT
-  // dg64 - get rid of _declspec
-  #undef SQLCLI_LIB_FUNC
-  #define SQLCLI_LIB_FUNC
-#endif
-
-#endif // DLL_EXPORT_DEFINES.h
diff --git a/core/sql/comexe/LateBindInfo.h b/core/sql/comexe/LateBindInfo.h
index 38afb40..668eeb0 100644
--- a/core/sql/comexe/LateBindInfo.h
+++ b/core/sql/comexe/LateBindInfo.h
@@ -51,7 +51,7 @@
 class Queue;
 class NAMemory;
 class ExpTupleDesc;
-class AnsiOrNskName;
+class AnsiName;
 class ResolvedNameListPre1800;
 
 // ---------------------------------------------------------------------
@@ -71,7 +71,7 @@ class ResolvedNameListPre1800;
 class UninitializedMvName : public NABasicObject
 {
 public:       
-    NA_EIDPROC UninitializedMvName();    
+    UninitializedMvName();    
 
     char * getPhysicalName() { return physicalName_; }
     char * getAnsiName() { return ansiName_; }
@@ -154,9 +154,6 @@ public:
   void setEnvVar(short v) { (v ? flags_ |= ENV_VAR : flags_ &= ~ENV_VAR); };
   NABoolean isEnvVar() { return (flags_ & ENV_VAR) != 0; };
 
-  void setDefine(short v) { (v ? flags_ |= DEFINE : flags_ &= ~DEFINE); };
-  NABoolean isDefine() { return (flags_ & DEFINE) != 0; };
-
   void setCachedParam(short v) { (v ? flags_ |= CACHED_PARAM : flags_ &= ~CACHED_PARAM); };
   NABoolean isCachedParam() { return (flags_ & CACHED_PARAM) != 0; };
 
@@ -169,20 +166,6 @@ public:
   void setView(short v) {(v ? flags_ |= IS_VIEW : flags_ &= ~IS_VIEW); };
   NABoolean isView() { return (flags_ & IS_VIEW) != 0; };
 
-  void setMPalias(short v) {(v ? flags_ |= IS_MPALIAS : flags_ &= ~IS_MPALIAS); };
-  NABoolean isMPalias() { return (flags_ & IS_MPALIAS) != 0; };
-
-// Set to avoid similarity check and recompilation
-  void setAvoidSimCheck(short v)
-  {
-    if (v) flags_ |= NAME_ONLY; else flags_ &= ~NAME_ONLY;
-  }
-  
-  // Force skipping the similarity check (while still resolving the
-  // physical name.) Used in special statements (e.g., SET TABLE TIMEOUT)
-  // when only the table name is needed, not its meta data 
-  NABoolean isAvoidSimCheck() { return((flags_ & NAME_ONLY) ? TRUE : FALSE); };
-
   void setAnsiNameChange(short v) { (v ? runtimeFlags_ |= ANSI_NAME_CHANGE : runtimeFlags_ &= ~ANSI_NAME_CHANGE); };
   NABoolean isAnsiNameChange() { return (runtimeFlags_ & ANSI_NAME_CHANGE) != 0; };
 
@@ -200,14 +183,11 @@ public:
   NABoolean isLastUsedNameCompEmbedded() { return (runtimeFlags_ & LASTUSED_NAME_STR_PTR) == 0; };
 
   static NABoolean makeSQLIdentifier(char * invalue, char * outvalue);
-  static NABoolean applyMPAliasDefaults(char * invalue, 
-					char * outvalue,
-					char * defValString);
   
-  AnsiOrNskName *getLastUsedName(NAMemory *heap);
+  AnsiName *getLastUsedName(NAMemory *heap);
   void setCompileTimeName(char *name, NAMemory *heap);
   void setLastUsedName(char *name, NAMemory *heap);
-  void setLastUsedName(AnsiOrNskName *name);
+  void setLastUsedName(AnsiName *name);
   Long pack(void *);
   Lng32 unpack(void *, void * reallocator);
 
@@ -259,12 +239,7 @@ private:
                               // Used when the variable name is the
                               // name of a resource fork.
     IS_INDEX = 0x0008,        // this is an index.
-    DEFINE = 0x0010,          // name is a guardian Define
     IS_VIEW = 0x0020,         // this is a view
-    IS_MPALIAS = 0x0040,      // the variable contains an mpalias name.
-    NAME_ONLY = 0x0080,        // variable, but only the table-name is needed
-                              // (not the table's meta-data.) So avoid simila
-                              // check and recompilation. Used by SET TIMEOUT
     COMP_NAME_STR_PTR = 0x0100, //  If not set, compileTimeAnsiName is the embedded string
     CACHED_PARAM = 0x0200 // prototyped hvar for cached tablenames.
   };
@@ -274,7 +249,7 @@ private:
     ANSI_NAME_CHANGE = 0x0001, IGNORE_TS = 0x0002, VIEW_NAME_CHANGE = 0x0004,
     RESERVED_NAME = 0x0008,
     LASTUSED_NAME_STR_PTR = 0x0010,
-    LASTUSED_NAME_CLASS_PTR =0x0020, // If set, LastUsedName points to AnsiOrNskName, else is the
+    LASTUSED_NAME_CLASS_PTR =0x0020, // If set, LastUsedName points to AnsiName, else is the
 				// character string embedded in LateBindInfo
   };
 
@@ -291,7 +266,7 @@ private:
   // Valid if this is a variable name and not an env var.
   Int16 inputListIndex_;                                          //  12- 13
 
-  // name of hvar/param/envVar/define used to input the table name.
+  // name of hvar/param/envVar used to input the table name.
   char varName_[MAX_ANSI_IDENTIFIER_LEN+1/*null terminator*/];    //  14-272
  
   // the ANSI name as known at compile time. Could be:
@@ -395,10 +370,6 @@ public:
   void getRecompLateNameInfoListPre1800(char * buffer);
   void resetRuntimeFlags();
 
-  NABoolean definePresent() { return (flags_ & DEFINE_PRESENT) != 0; };
-  void setDefinePresent(short v) 
-  { (v ? flags_ |= DEFINE_PRESENT : flags_ &= ~DEFINE_PRESENT); };
-
   NABoolean viewPresent() { return (flags_ & VIEW_PRESENT) != 0; };
   void setViewPresent(short v) 
   { (v ? flags_ |= VIEW_PRESENT : flags_ &= ~VIEW_PRESENT); };
@@ -415,13 +386,12 @@ public:
 private:
   enum Flags
   { 
-    DEFINE_PRESENT = 0x0001, // one or more DEFINEs used in query
     VIEW_PRESENT = 0x0002,   // one or more views used in query
     ENVVARS_PRESENT = 0x0004, // one or more envvars as tablenames used
                               // in the query.
     VARIABLE_PRESENT = 0x0008 // one of more tablenames used in the query
                               // are passed in as variables.
-                              // (hostvar, defines or envvars)
+                              // (hostvar, envvars)
   };
  
   UInt32 flags_;                                                //   00-  03
@@ -436,21 +406,18 @@ private:
 // ---------------------------------------------------------------------
 typedef NAVersionedObjectPtrTempl<LateNameInfoList> LateNameInfoListPtr;
 
-class AnsiOrNskName : public NABasicObject
+class AnsiName : public NABasicObject
 {
 public:
-  AnsiOrNskName(char *inName);
+  AnsiName(char *inName);
   
   char *getInternalName() ;
   char *getExternalName() ;
   Int16 extractParts(Lng32 &numParts,
 		char *parts[]);
-  Int16 equals(AnsiOrNskName *name);
-  Int16 convertAnsiOrNskName(bool doCheck = TRUE);
+  Int16 equals(AnsiName *name);
+  Int16 convertAnsiName(bool doCheck = TRUE);
   Int16 fillInMissingParts(char *schemaName);
-  bool  isNskName();
-  Int16 updateNSKInternalName(char *inName);
-  Int16 quoteNSKExtName();
 private:
 
   char  extName_[MAX_ANSI_NAME_LENGTH]; // Given (external) 3-part name
@@ -460,13 +427,11 @@ private:
   // for the 3-part interal name the same as that for the 3-part external name.
   char	intName_[MAX_ANSI_NAME_LENGTH];
   Int16 noOfParts_;
-  bool  isNskName_; // TRUE if NSK name, FALSE if ansi name
   char  parts_[4][ComMAX_1_PART_EXTERNAL_UTF8_NAME_LEN_IN_BYTES+1]; // in UTF8
   bool  isValid_;  // The flag that denotes if the name is checked and extracted into parts
   bool  isError_;  
 };
 
-
 ///////////////////////////////////////////////////////////
 // class TrafSimilarityTableInfo
 ///////////////////////////////////////////////////////////

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/comexe/PartInputDataDesc.cpp
----------------------------------------------------------------------